@@ -175,7 +175,7 @@ gupnp_control_point_dispose (GObject *object)
                 data = control_point->priv->pending_gets->data;
 
                 context = gupnp_control_point_get_context (control_point);
-                session = _gupnp_context_get_session (context);
+                session = gupnp_context_get_session (context);
 
                 soup_session_cancel_message (session,
                                              data->message,
@@ -432,8 +432,8 @@ got_description_url (SoupSession           *session,
                 xmlDoc *xml_doc;
 
                 /* Parse response */
-                xml_doc = xmlParseMemory (msg->response_body->data,
-                                          msg->response_body->length);
+                xml_doc = xmlRecoverMemory (msg->response_body->data,
+                                            msg->response_body->length);
                 if (xml_doc) {
                         doc = xml_doc_wrapper_new (xml_doc);
 
@@ -499,7 +499,7 @@ load_description (GUPnPControlPoint *control_point,
 
                 context = gupnp_control_point_get_context (control_point);
 
-                session = _gupnp_context_get_session (context);
+                session = gupnp_context_get_session (context);
 
                 data = g_slice_new (GetDescriptionURLData);
 
